<?php
/**
 * API file to sync user passwords with their group passwords
 */

/**
 * Function to sync user passwords with their group passwords
 * This updates both user_pass and user_pass_clear fields
 * 
 * @return string Message indicating result of operation
 */
function sync_user_passwords() {
    global $pdo; // Make sure this matches your database connection variable
    
    // Check if $pdo is available
    if (!isset($pdo) || !$pdo) {
        // Try to get database connection from your system
        if (isset($GLOBALS['pdo'])) {
            $pdo = $GLOBALS['pdo'];
        } else {
            return "Error: Database connection not available";
        }
    }
    
    try {
        // Run the password sync query
        $query = "
            UPDATE wp_users u
            JOIN wp_groups g ON u.group_id = g.id
            SET u.user_pass = g.group_pass,
                u.user_pass_clear = g.group_pass_clear
            WHERE u.group_id IS NOT NULL
        ";
        
        $stmt = $pdo->prepare($query);
        $result = $stmt->execute();
        
        if ($result) {
            $affected = $stmt->rowCount();
            return "Password synchronization complete. $affected account(s) updated.";
        } else {
            return "Error: Synchronization failed. " . implode(', ', $pdo->errorInfo());
        }
    } catch (Exception $e) {
        return "Error: " . $e->getMessage();
    }
}
?>