function formatPreopMessage(preopMsg) {
  const sections = [
    { name: 'title', icon: 'fa-user-md', class: 'preop-main-title' },
    { name: 'History of Present Illness', icon: 'fa-clock', class: 'preop-title-history' },
    { name: 'Past Medical History', icon: 'fa-notes-medical', class: 'preop-title-medical' },
    { name: 'Family History', icon: 'fa-users', class: 'preop-title-family' },
    { name: 'Physical Exam', icon: 'fa-stethoscope', class: 'preop-title-physical' },
    { name: 'Labs', icon: 'fa-vial', class: 'preop-title-labs' },
    { name: 'NPO Status', icon: 'fa-utensils', class: 'preop-title-status' },
    { name: 'Patient and Surgeon Requests', icon: 'fa-user-md', class: 'preop-title-surgeon' }
  ];

  let formattedMsg = '';
  let lines = preopMsg.trim().split('\n');
  let currentSection = null;

  function formatContent(content) {
    return content.replace(/^(.+):\s*/gm, '<b>$1:</b> ');
  }

  lines.forEach((line, index) => {
    const trimmedLine = line.trim();
    const matchedSection = sections.find(section => 
      trimmedLine.toLowerCase() === section.name.toLowerCase() || 
      (index === 0 && section.name === 'title')
    );

    if (matchedSection) {
      if (currentSection) {
        formattedMsg += '</span>\n\n';
      }
      currentSection = matchedSection;
      formattedMsg += `<i class="fas ${matchedSection.icon}"></i><span class="${matchedSection.class}">${trimmedLine}</span>\n\n<span class="preop-content">`;
    } else if (trimmedLine) {
      formattedMsg += formatContent(trimmedLine) + '<br>';
    }
  });

  if (currentSection) {
    formattedMsg += '</span>';
  }

  return formattedMsg;
}

// Modify the ShowPreopScreen use formatPreopMessage
window.ShowPreopScreen = function() {
    UserShowingWhatNowFlag = false;

    var displayContent = $("divDisplayContent");
    if (displayContent) {
        displayContent.innerHTML = "";
        displayContent.style.height = MyContentHeight + "px";
    }

    var caseLog = $("divCaseLog2");
    if (caseLog && typeof caseLog.hide === "function") {
        caseLog.hide();
    }

    var divWrapper = document.createElement("div");
    divWrapper.setAttribute("id", "divPreopWrapper");
    if (displayContent) {
        displayContent.appendChild(divWrapper);
    }

    var divScroll = document.createElement("div");
    divScroll.setAttribute("id", "preopScroller");
    divWrapper.appendChild(divScroll);

    var preopDiv = document.createElement("div");

    if (CurrentCase && CurrentCase.preopMsg) {
        try {
            preopDiv.innerHTML = formatPreopMessage(CurrentCase.preopMsg);
        } catch (error) {
            preopDiv.textContent = CurrentCase.preopMsg;
        }
    }

    divScroll.appendChild(preopDiv);

    if (typeof CreateScroller === "function") {
        CreateScroller("preopScroller");
    }
};

// Call the function
ShowPreopScreen();

function handleButtonClick(action) {
    if (typeof CurrentCase !== 'undefined' && CurrentCase) {
        // Case is running
        switch(action) {
            case 'preop':
                ShowPreopScreen();
                break;
            case 'case-help':
                ShowCaseHelpScreen();
                break;
            case 'case-log':
                ShowCaseLogScreen();
                break;
            case 'new-case':
                ShowNewCaseScreen();
                break;
            default:
                console.warn('Unknown action:', action);
        }
    } else if (action === 'new-case') {
        var caseList = document.getElementById('caseList');
        var selectedCase = caseList ? caseList.value : null;
        if (!selectedCase || selectedCase === 'defaultCase') {
            window.location.href = '/';
            return false;
        }

        var caseAccess = checkCaseAccess(selectedCase);
        if (!caseAccess.isAccessible) {
            UserCaseRunning = false;
            if (typeof MyTimeout !== 'undefined') {
                clearTimeout(MyTimeout);
            }
            switch(caseAccess.reason) {
                case 'subscription-expired':
                    alert('Your subscription has expired. Please renew to access this case.');
                    break;
                case 'requires-pro':
                    alert('This case requires a Pro subscription.');
                    break;
                case 'invalid-case':
                    alert('Invalid case selected.');
                    break;
            }
            ShowNewCaseScreen();
            return false;
        }
        window.location.href = '/';
    }
}

function checkCaseAccess(caseId) {
    if (!window.CaseData || !window.CaseData[caseId]) {
        return { isAccessible: false, reason: 'invalid-case' };
    }
    
    var requiresPro = window.CaseData[caseId] && window.CaseData[caseId].requiresPro || false;
    var userHasPro = window.userStatus === 'Pro';
    var userExpiration = window.userExpiration ? new Date(window.userExpiration) : null;
    var isExpired = userExpiration && userExpiration < new Date();
    
    if (isExpired) {
        return { isAccessible: !requiresPro, reason: 'subscription-expired' };
    }
    
    if (requiresPro && !userHasPro) {
        return { isAccessible: false, reason: 'requires-pro' };
    }
    
    return { isAccessible: true };
}

// exit case popup functionality
const exitWarningModal = document.getElementById('exitWarningModal');
let pendingNavigationUrl = null;

// Add target tab handling
window.handleSettingsNavigation = function(e, type) {
    if (typeof CurrentCase !== 'undefined' && CurrentCase) {
        e.preventDefault();
        e.stopPropagation();
        
        // Store which tab to show
        if (type === 'cases') {
            sessionStorage.setItem('showCases', 'true');
        } else if (type === 'details') {
            sessionStorage.setItem('showDetails', 'true');
        } else if (type === 'change') {
            sessionStorage.setItem('showChangeSettings', 'true');
        }
        
        pendingNavigationUrl = '/settings';
        if (exitWarningModal) {
            exitWarningModal.style.display = 'block';
            setupModalButtons();
        }
        return true;
    }
    return false;
};

function handleExitWarning(e) {
    /* console.log('Exit warning handler triggered', {
        target: e.target,
        currentCase: typeof CurrentCase !== 'undefined' ? CurrentCase : 'undefined',
        modal: exitWarningModal ? 'exists' : 'missing'
    }); */
    
    // First check if it's the settings button in menu
    const settingsBtn = e.target.closest('.my-settings-btn');
    if (settingsBtn) {
        // console.log('Settings button clicked');
        if (typeof CurrentCase !== 'undefined' && CurrentCase) {
            e.preventDefault();
            pendingNavigationUrl = settingsBtn.querySelector('a').href;
            exitWarningModal.style.display = 'block';
            setupModalButtons();
        }
        return;
    }
    
    const trigger = e.target.closest([
        '.my-account',
        '.logo a', 
        '.footer-menu a',
        'button.logout',
        'a.logout',
        '.view-my-cases',
        '.view-my-settings',
        '.view-cases',
        '.view-settings',
        '.change-my-settings',
        '.settings-active',
        '.change-settings',
        '.settings-switch div',
        '.super-admin-link',
        '.site-tag a',
        '.dev-tag a'
    ].join(','));

    // console.log('Trigger element:', trigger);
    if (!trigger) {
        return;
    }
    
    // Special handling for home link
    if (trigger.classList.contains('home-link') || trigger.closest('.logo')) {
        trigger.target = '_self';
    }
    
    if (typeof CurrentCase !== 'undefined' && CurrentCase) {
        // console.log('Showing exit warning modal');
        e.preventDefault();
        e.stopPropagation();
        pendingNavigationUrl = trigger.href || null;
        
        if (exitWarningModal) {
            exitWarningModal.style.display = 'block';
            setupModalButtons();
        } else {
            // console.error('Exit warning modal not found');
        }
    } else {
        // console.log('No current case, proceeding with navigation');
    }
}

function setupModalButtons() {
    const btns = {
        save: document.getElementById('saveAndExitBtn'),
        continue: document.getElementById('exitWithoutSaveBtn'),
        cancel: document.getElementById('cancelExitBtn')
    };

    if (btns.save) {
        btns.save.onclick = function() {
            // First show case log screen to generate the log content
            ShowCaseLogScreen();
            
            // Now try to save
            if (typeof saveCaseData === 'function') {
                try {
                    saveCaseData();
                    handleExit();
                } catch (error) {
                    // console.error('Error saving case:', error);
                }
            }
        };
    }

    if (btns.continue) {
        btns.continue.onclick = function() {
            handleExit();
        };
    }

    if (btns.cancel) {
        btns.cancel.onclick = function() {
            exitWarningModal.style.display = 'none';
            pendingNavigationUrl = null;
        };
    }
}

document.addEventListener('DOMContentLoaded', function() {
    // Add click handler to entire document
    document.addEventListener('click', handleExitWarning);

    // Add beforeunload handler
    window.onbeforeunload = function(e) {
        // Only show browser alert if NOT triggered by our exit handler
        if (typeof CurrentCase !== 'undefined' && CurrentCase && !pendingNavigationUrl) {
            e.preventDefault();
            e.returnValue = '';
        }
    };
});

function handleExit() {
    clearTimeout(MyTimeout);
    CurrentCase = null;
    exitWarningModal.style.display = 'none';
    if (pendingNavigationUrl) {
        window.location.href = pendingNavigationUrl;
    } else {
        ShowNewCaseScreen();
    }
}